@@ -1,3 +1,7 @@
+package HTML::HTML5::Parser::NamedEntityList;
+
+our $VERSION = '0.102';
+
 $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "AElig" => "\306",
           "AElig;" => "\306",
@@ -335,31 +339,50 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "NotDoubleVerticalBar;" => "\x{2226}",
           "NotElement;" => "\x{2209}",
           "NotEqual;" => "\x{2260}",
+			 "NotEqualTilde;" => "\x{2242}\x{338}",
           "NotExists;" => "\x{2204}",
           "NotGreater;" => "\x{226f}",
           "NotGreaterEqual;" => "\x{2271}",
+          "NotGreaterFullEqual;" => "\x{2267}\x{338}",
+          "NotGreaterGreater;" => "\x{226b}\x{338}",
           "NotGreaterLess;" => "\x{2279}",
+          "NotGreaterSlantEqual;" => "\x{2a7e}\x{338}",
           "NotGreaterTilde;" => "\x{2275}",
+          "NotHumpDownHump;" => "\x{224e}\x{338}",
+          "NotHumpEqual;" => "\x{224f}\x{338}",
           "NotLeftTriangle;" => "\x{22ea}",
+          "NotLeftTriangleBar;" => "\x{29cf}\x{338}",
           "NotLeftTriangleEqual;" => "\x{22ec}",
           "NotLess;" => "\x{226e}",
           "NotLessEqual;" => "\x{2270}",
           "NotLessGreater;" => "\x{2278}",
+          "NotLessLess;" => "\x{226a}\x{338}",
+          "NotLessSlantEqual;" => "\x{2a7d}\x{338}",
           "NotLessTilde;" => "\x{2274}",
+          "NotNestedGreaterGreater;" => "\x{2aa2}\x{338}",
+          "NotNestedLessLess;" => "\x{2aa1}\x{338}",
           "NotPrecedes;" => "\x{2280}",
+          "NotPrecedesEqual;" => "\x{2aaf}\x{338}",
           "NotPrecedesSlantEqual;" => "\x{22e0}",
           "NotReverseElement;" => "\x{220c}",
           "NotRightTriangle;" => "\x{22eb}",
+          "NotRightTriangleBar;" => "\x{29d0}\x{338}",
           "NotRightTriangleEqual;" => "\x{22ed}",
+          "NotSquareSubset;" => "\x{228f}\x{338}",
           "NotSquareSubsetEqual;" => "\x{22e2}",
+          "NotSquareSuperset;" => "\x{2290}\x{338}",
           "NotSquareSupersetEqual;" => "\x{22e3}",
+          "NotSubset;" => "\x{2282}\x{20d2}",
           "NotSubsetEqual;" => "\x{2288}",
           "NotSucceeds;" => "\x{2281}",
+          "NotSucceedsEqual;" => "\x{2ab0}\x{338}",
           "NotSucceedsSlantEqual;" => "\x{22e1}",
+          "NotSucceedsTilde;" => "\x{227f}\x{338}",
+          "NotSuperset;" => "\x{2283}\x{20d2}",
           "NotSupersetEqual;" => "\x{2289}",
           "NotTilde;" => "\x{2241}",
           "NotTildeEqual;" => "\x{2244}",
-          "NotTildeFullEqual;" => "\x{2247}",
+    		  "NotTildeFullEqual;" => "\x{2247}",
           "NotTildeTilde;" => "\x{2249}",
           "NotVerticalBar;" => "\x{2224}",
           "Nscr;" => "\x{1d4a9}",
@@ -391,7 +414,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "Otimes;" => "\x{2a37}",
           "Ouml" => "\326",
           "Ouml;" => "\326",
-          "OverBar;" => "\257",
+          "OverBar;" => "\x{203e}",
           "OverBrace;" => "\x{23de}",
           "OverBracket;" => "\x{23b4}",
           "OverParenthesis;" => "\x{23dc}",
@@ -517,6 +540,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "Tfr;" => "\x{1d517}",
           "Therefore;" => "\x{2234}",
           "Theta;" => "\x{398}",
+          "ThickSpace;" => "\x{205f}\x{200a}",
           "ThinSpace;" => "\x{2009}",
           "Tilde;" => "\x{223c}",
           "TildeEqual;" => "\x{2243}",
@@ -540,7 +564,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "Ugrave" => "\331",
           "Ugrave;" => "\331",
           "Umacr;" => "\x{16a}",
-          "UnderBar;" => "\x{332}",
+          "UnderBar;" => "_",
           "UnderBrace;" => "\x{23df}",
           "UnderBracket;" => "\x{23b5}",
           "UnderParenthesis;" => "\x{23dd}",
@@ -617,6 +641,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "aacute;" => "\341",
           "abreve;" => "\x{103}",
           "ac;" => "\x{223e}",
+          "acE;" => "\x{223e}\x{333}",
           "acd;" => "\x{223f}",
           "acirc" => "\342",
           "acirc;" => "\342",
@@ -729,6 +754,8 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "blk14;" => "\x{2591}",
           "blk34;" => "\x{2593}",
           "block;" => "\x{2588}",
+          "bne;" => "=\x{20e5}",
+          "bnequiv;" => "\x{2261}\x{20e5}",
           "bnot;" => "\x{2310}",
           "bopf;" => "\x{1d553}",
           "bot;" => "\x{22a5}",
@@ -802,6 +829,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "capcap;" => "\x{2a4b}",
           "capcup;" => "\x{2a47}",
           "capdot;" => "\x{2a40}",
+          "caps;" => "\x{2229}\x{fe00}",
           "caret;" => "\x{2041}",
           "caron;" => "\x{2c7}",
           "ccaps;" => "\x{2a4d}",
@@ -877,6 +905,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "cupcup;" => "\x{2a4a}",
           "cupdot;" => "\x{228d}",
           "cupor;" => "\x{2a45}",
+          "cups;" => "\x{222a}\x{fe00}",
           "curarr;" => "\x{21b7}",
           "curarrm;" => "\x{293c}",
           "curlyeqprec;" => "\x{22de}",
@@ -997,9 +1026,9 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "epar;" => "\x{22d5}",
           "eparsl;" => "\x{29e3}",
           "eplus;" => "\x{2a71}",
-          "epsi;" => "\x{3f5}",
+          "epsi;" => "\x{3b5}",
           "epsilon;" => "\x{3b5}",
-          "epsiv;" => "\x{3b5}",
+          "epsiv;" => "\x{3f5}",
           "eqcirc;" => "\x{2256}",
           "eqcolon;" => "\x{2255}",
           "eqsim;" => "\x{2242}",
@@ -1033,6 +1062,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "ffllig;" => "\x{fb04}",
           "ffr;" => "\x{1d523}",
           "filig;" => "\x{fb01}",
+          "fjlig;" => "fj",
           "flat;" => "\x{266d}",
           "fllig;" => "\x{fb02}",
           "fltns;" => "\x{25b1}",
@@ -1083,6 +1113,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "gesdot;" => "\x{2a80}",
           "gesdoto;" => "\x{2a82}",
           "gesdotol;" => "\x{2a84}",
+          "gesl;" => "\x{22db}\x{fe00}",
           "gesles;" => "\x{2a94}",
           "gfr;" => "\x{1d524}",
           "gg;" => "\x{226b}",
@@ -1120,6 +1151,8 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "gtreqqless;" => "\x{2a8c}",
           "gtrless;" => "\x{2277}",
           "gtrsim;" => "\x{2273}",
+          "gvertneqq;" => "\x{2269}\x{fe00}",
+          "gvnE;" => "\x{2269}\x{fe00}",
           "hArr;" => "\x{21d4}",
           "hairsp;" => "\x{200a}",
           "half;" => "\275",
@@ -1251,6 +1284,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "lat;" => "\x{2aab}",
           "latail;" => "\x{2919}",
           "late;" => "\x{2aad}",
+          "lates;" => "\x{2aad}\x{fe00}",
           "lbarr;" => "\x{290c}",
           "lbbrk;" => "\x{2772}",
           "lbrace;" => "{",
@@ -1289,6 +1323,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "lesdot;" => "\x{2a7f}",
           "lesdoto;" => "\x{2a81}",
           "lesdotor;" => "\x{2a83}",
+          "lesg;" => "\x{22da}\x{fe00}",
           "lesges;" => "\x{2a93}",
           "lessapprox;" => "\x{2a85}",
           "lessdot;" => "\x{22d6}",
@@ -1372,6 +1407,8 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "ltrif;" => "\x{25c2}",
           "lurdshar;" => "\x{294a}",
           "luruhar;" => "\x{2966}",
+          "lvertneqq;" => "\x{2268}\x{fe00}",
+          "lvnE;" => "\x{2268}\x{fe00}",
           "mDDot;" => "\x{223a}",
           "macr" => "\257",
           "macr;" => "\257",
@@ -1412,14 +1449,23 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "mu;" => "\x{3bc}",
           "multimap;" => "\x{22b8}",
           "mumap;" => "\x{22b8}",
+          "nGg;" => "\x{22d9}\x{338}",
+          "nGt;" => "\x{226b}\x{20d2}",
+          "nGtv;" => "\x{226b}\x{338}",
           "nLeftarrow;" => "\x{21cd}",
           "nLeftrightarrow;" => "\x{21ce}",
+          "nLl;" => "\x{22d8}\x{338}",
+          "nLt;" => "\x{226a}\x{20d2}",
+          "nLtv;" => "\x{226a}\x{338}",
           "nRightarrow;" => "\x{21cf}",
           "nVDash;" => "\x{22af}",
           "nVdash;" => "\x{22ae}",
           "nabla;" => "\x{2207}",
           "nacute;" => "\x{144}",
+          "nang;" => "\x{2220}\x{20d2}",
           "nap;" => "\x{2249}",
+          "napE;" => "\x{2a70}\x{338}",
+          "napid;" => "\x{224b}\x{338}",
           "napos;" => "\x{149}",
           "napprox;" => "\x{2249}",
           "natur;" => "\x{266e}",
@@ -1427,10 +1473,13 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "naturals;" => "\x{2115}",
           "nbsp" => "\240",
           "nbsp;" => "\240",
+          "nbump;" => "\x{224e}\x{338}",
+          "nbumpe;" => "\x{224f}\x{338}",
           "ncap;" => "\x{2a43}",
           "ncaron;" => "\x{148}",
           "ncedil;" => "\x{146}",
           "ncong;" => "\x{2247}",
+          "ncongdot;" => "\x{2a6d}\x{338}",
           "ncup;" => "\x{2a42}",
           "ncy;" => "\x{43d}",
           "ndash;" => "\x{2013}",
@@ -1439,13 +1488,19 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "nearhk;" => "\x{2924}",
           "nearr;" => "\x{2197}",
           "nearrow;" => "\x{2197}",
+          "nedot;" => "\x{2250}\x{338}",
           "nequiv;" => "\x{2262}",
           "nesear;" => "\x{2928}",
+          "nesim;" => "\x{2242}\x{338}",
           "nexist;" => "\x{2204}",
           "nexists;" => "\x{2204}",
           "nfr;" => "\x{1d52b}",
+          "ngE;" => "\x{2267}\x{338}",
           "nge;" => "\x{2271}",
           "ngeq;" => "\x{2271}",
+          "ngeqq;" => "\x{2267}\x{338}",
+          "ngeqslant;" => "\x{2a7e}\x{338}",
+          "nges;" => "\x{2a7e}\x{338}",
           "ngsim;" => "\x{2275}",
           "ngt;" => "\x{226f}",
           "ngtr;" => "\x{226f}",
@@ -1458,12 +1513,16 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "niv;" => "\x{220b}",
           "njcy;" => "\x{45a}",
           "nlArr;" => "\x{21cd}",
+          "nlE;" => "\x{2266}\x{338}",
           "nlarr;" => "\x{219a}",
           "nldr;" => "\x{2025}",
           "nle;" => "\x{2270}",
           "nleftarrow;" => "\x{219a}",
           "nleftrightarrow;" => "\x{21ae}",
           "nleq;" => "\x{2270}",
+          "nleqq;" => "\x{2266}\x{338}",
+          "nleqslant;" => "\x{2a7d}\x{338}",
+          "nles;" => "\x{2a7d}\x{338}",
           "nless;" => "\x{226e}",
           "nlsim;" => "\x{2274}",
           "nlt;" => "\x{226e}",
@@ -1474,6 +1533,8 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "not" => "\254",
           "not;" => "\254",
           "notin;" => "\x{2209}",
+          "notinE;" => "\x{22f9}\x{338}",
+          "notindot;" => "\x{22f5}\x{338}",
           "notinva;" => "\x{2209}",
           "notinvb;" => "\x{22f7}",
           "notinvc;" => "\x{22f6}",
@@ -1483,17 +1544,24 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "notnivc;" => "\x{22fd}",
           "npar;" => "\x{2226}",
           "nparallel;" => "\x{2226}",
+          "nparsl;" => "\x{2afd}\x{20e5}",
+          "npart;" => "\x{2202}\x{338}",
           "npolint;" => "\x{2a14}",
           "npr;" => "\x{2280}",
           "nprcue;" => "\x{22e0}",
+          "npre;" => "\x{2aaf}\x{338}",
           "nprec;" => "\x{2280}",
+          "npreceq;" => "\x{2aaf}\x{338}",
           "nrArr;" => "\x{21cf}",
           "nrarr;" => "\x{219b}",
+          "nrarrc;" => "\x{2933}\x{338}",
+          "nrarrw;" => "\x{219d}\x{338}",
           "nrightarrow;" => "\x{219b}",
           "nrtri;" => "\x{22eb}",
           "nrtrie;" => "\x{22ed}",
           "nsc;" => "\x{2281}",
           "nsccue;" => "\x{22e1}",
+          "nsce;" => "\x{2ab0}\x{338}",
           "nscr;" => "\x{1d4c3}",
           "nshortmid;" => "\x{2224}",
           "nshortparallel;" => "\x{2226}",
@@ -1505,12 +1573,19 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "nsqsube;" => "\x{22e2}",
           "nsqsupe;" => "\x{22e3}",
           "nsub;" => "\x{2284}",
+          "nsubE;" => "\x{2ac5}\x{338}",
           "nsube;" => "\x{2288}",
+          "nsubset;" => "\x{2282}\x{20d2}",
           "nsubseteq;" => "\x{2288}",
+          "nsubseteqq;" => "\x{2ac5}\x{338}",
           "nsucc;" => "\x{2281}",
+          "nsucceq;" => "\x{2ab0}\x{338}",
           "nsup;" => "\x{2285}",
+          "nsupE;" => "\x{2ac6}\x{338}",
           "nsupe;" => "\x{2289}",
+          "nsupset;" => "\x{2283}\x{20d2}",
           "nsupseteq;" => "\x{2289}",
+          "nsupseteqq;" => "\x{2ac6}\x{338}",
           "ntgl;" => "\x{2279}",
           "ntilde" => "\361",
           "ntilde;" => "\361",
@@ -1525,10 +1600,18 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "numsp;" => "\x{2007}",
           "nvDash;" => "\x{22ad}",
           "nvHarr;" => "\x{2904}",
+          "nvap;" => "\x{224d}\x{20d2}",
           "nvdash;" => "\x{22ac}",
+          "nvge;" => "\x{2265}\x{20d2}",
+          "nvgt;" => ">\x{20d2}",
           "nvinfin;" => "\x{29de}",
           "nvlArr;" => "\x{2902}",
+          "nvle;" => "\x{2264}\x{20d2}",
+          "nvlt;" => "<\x{20d2}",
+          "nvltrie;" => "\x{22b4}\x{20d2}",
           "nvrArr;" => "\x{2903}",
+          "nvrtrie;" => "\x{22b5}\x{20d2}",
+          "nvsim;" => "\x{223c}\x{20d2}",
           "nwArr;" => "\x{21d6}",
           "nwarhk;" => "\x{2923}",
           "nwarr;" => "\x{2196}",
@@ -1610,7 +1693,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "pertenk;" => "\x{2031}",
           "pfr;" => "\x{1d52d}",
           "phi;" => "\x{3c6}",
-          "phiv;" => "\x{3c6}",
+          "phiv;" => "\x{3c5}",
           "phmmat;" => "\x{2133}",
           "phone;" => "\x{260e}",
           "pi;" => "\x{3c0}",
@@ -1680,6 +1763,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "rAtail;" => "\x{291c}",
           "rBarr;" => "\x{290f}",
           "rHar;" => "\x{2964}",
+          "race;" => "\x{223d}\x{331}",
           "racute;" => "\x{155}",
           "radic;" => "\x{221a}",
           "raemptyv;" => "\x{29b3}",
@@ -1839,6 +1923,7 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "smile;" => "\x{2323}",
           "smt;" => "\x{2aaa}",
           "smte;" => "\x{2aac}",
+          "smtes;" => "\x{2aac}\x{fe00}",
           "softcy;" => "\x{44c}",
           "sol;" => "/",
           "solb;" => "\x{29c4}",
@@ -1848,7 +1933,9 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "spadesuit;" => "\x{2660}",
           "spar;" => "\x{2225}",
           "sqcap;" => "\x{2293}",
+          "sqcaps;" => "\x{2293}\x{fe00}",
           "sqcup;" => "\x{2294}",
+          "sqcups;" => "\x{2294}\x{fe00}",
           "sqsub;" => "\x{228f}",
           "sqsube;" => "\x{2291}",
           "sqsubset;" => "\x{228f}",
@@ -2048,15 +2135,19 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "vBarv;" => "\x{2ae9}",
           "vDash;" => "\x{22a8}",
           "vangrt;" => "\x{299c}",
-          "varepsilon;" => "\x{3b5}",
+          "varepsilon;" => "\x{3f5}",
           "varkappa;" => "\x{3f0}",
           "varnothing;" => "\x{2205}",
-          "varphi;" => "\x{3c6}",
+          "varphi;" => "\x{3d5}",
           "varpi;" => "\x{3d6}",
           "varpropto;" => "\x{221d}",
           "varr;" => "\x{2195}",
           "varrho;" => "\x{3f1}",
           "varsigma;" => "\x{3c2}",
+          "varsubsetneq;" => "\x{228a}\x{fe00}",
+          "varsubsetneqq;" => "\x{2acb}\x{fe00}",
+          "varsupsetneq;" => "\x{228b}\x{fe00}",
+          "varsupsetneqq;" => "\x{2acc}\x{fe00}",
           "vartheta;" => "\x{3d1}",
           "vartriangleleft;" => "\x{22b2}",
           "vartriangleright;" => "\x{22b3}",
@@ -2070,10 +2161,16 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "vert;" => "|",
           "vfr;" => "\x{1d533}",
           "vltri;" => "\x{22b2}",
+          "vnsub;" => "\x{2282}\x{20d2}",
+          "vnsup;" => "\x{2283}\x{20d2}",
           "vopf;" => "\x{1d567}",
           "vprop;" => "\x{221d}",
           "vrtri;" => "\x{22b3}",
           "vscr;" => "\x{1d4cb}",
+          "vsubnE;" => "\x{2acb}\x{fe00}",
+          "vsubne;" => "\x{228a}\x{fe00}",
+          "vsupnE;" => "\x{2acc}\x{fe00}",
+          "vsupne;" => "\x{228b}\x{fe00}",
           "vzigzag;" => "\x{299a}",
           "wcirc;" => "\x{175}",
           "wedbar;" => "\x{2a5f}",
@@ -2136,9 +2233,11 @@ $HTML::HTML5::Parser::TagSoupParser::EntityChar = {
           "zopf;" => "\x{1d56b}",
           "zscr;" => "\x{1d4cf}",
           "zwj;" => "\x{200d}",
-          "zwnj;" => "\x{200c}"
+          "zwnj;" => "\x{200c}",
         };
+
 1;
+
 __DATA__
 
 =head1 NAME
@@ -2153,17 +2252,17 @@ It is referenced by C<HTML::HTML5::Parser::Tokenizer>.
 
 =head1 SEE ALSO
 
-L<HTML::HTML5::Parser>. 
+L<HTML::HTML5::Parser>.
 
-HTML 5 - Entities
-<http://www.whatwg.org/specs/web-apps/current-work/#entities>
+Web Applications 1.0 - Named character references
+L<http://www.whatwg.org/specs/web-apps/current-work/complete.html#named-character-references>.
 
 =head1 LICENSE
 
 (C) Copyright 2004-2007 Apple Computer, Inc., Mozilla Foundation,
 and Opera Software ASA.
 
-Copyright 2007 Wakaba <w@suika.fam.cx>.
+Copyright 2007-2010 Wakaba <w@suika.fam.cx>.
 
 Copyright 2009-2010 Toby Inkster <tobyink@cpan.org>.
 
